@@ -46,10 +46,16 @@ def negative_distances(negative_mining_strategy: str,
     """Negative distance computation.
 
     Args:
-        negative_mining_strategy (str, optional): [description].
+        negative_mining_strategy: What mining strategy to use for select the
+        embedding from the different class.
+        Available: {'hard', 'semi-hard', 'easy'}
+
         distances: 2-D float `Tensor` of [n, n] pairwise distances.
+
         negative_mask: 2-D Boolean `Tensor` of [n, n] valid distance size.
+
         positive_mask: 2-D Boolean `Tensor` of [n, n] valid distance size.
+
         batch_size: The current batch size.
 
     Raises:
@@ -101,9 +107,12 @@ def compute_loss(positive_distances: FloatTensor,
 
     Args:
         positive_distances: An [n,1] FloatTensor of positive distances.
+
         negative_distances: An [n,1] FloatTensor of negative distances.
-        soft_margin (bool, optional): [description]. Defaults to False.
-        margin (float, optional): [description]. Defaults to 1.0.
+
+        soft_margin: [description]. Defaults to False.
+
+        margin: [description]. Defaults to 1.0.
 
     Returns:
         An [n,1] FloatTensor containing the loss for each example.
@@ -118,3 +127,45 @@ def compute_loss(positive_distances: FloatTensor,
         loss = tf.maximum(loss, 0.0)  # numeric stability
 
     return loss
+
+
+@tf.keras.utils.register_keras_serializable(package="Similarity")
+@tf.function
+def logsumexp(pairwise_distances: FloatTensor,
+              mask: FloatTensor) -> Any:
+    """Compute the LogSumExp across axis 1 of the pairwise distance matrix.
+
+    This function:
+    * Avoids numerical instablity when the inputs are large or small.
+    * Adds 1 to the reduce_sum of the exp to ensure the loss is positive
+    * masks out the result of exp to ensure that masked values are not included
+      in the log sum.
+
+    Args:
+        pairwise_distance: A 2D FloatTensor of the pairwise distances.
+
+        mask: A 2D FloatTensor with 1.0 for all valid values and 0.0
+        everywhere else.
+
+    returns:
+        A [n, 1] FloatTensor containing the per example LogSumExp values.
+    """
+    raw_max = tf.math.reduce_max(
+        pairwise_distances,
+        axis=1,
+        keepdims=True
+    )
+    my_max = tf.stop_gradient(
+        tf.where(
+            tf.math.is_finite(raw_max),
+            raw_max,
+            tf.zeros_like(raw_max)
+        )
+    )
+    x = tf.math.subtract(pairwise_distances, my_max)
+    x = tf.math.exp(x) * mask
+    x = tf.math.reduce_sum(x, axis=1, keepdims=True)
+    x = tf.math.log(1 + x)
+    x = tf.math.add(x, my_max)
+
+    return x
